@@ -117,8 +117,7 @@ config_load() {
 	_tmp="$(mktemp -t robsd.XXXXXX)"
 	{
 		cat
-		echo "EXECDIR=\${execdir}"
-	} | "$ROBSDCONFIG" -m "$_MODE" ${ROBSDCONF:+"-f${ROBSDCONF}"} "$@" - \
+	} | "$ROBSDCONFIG" -m "$_MODE" ${ROBSDCONF:+"-C${ROBSDCONF}"} "$@" - \
 		>"$_tmp" || _err="$?"
 	[ "$_err" -eq 0 ] && eval "$(<"$_tmp")"
 	rm "$_tmp"
@@ -149,7 +148,8 @@ config_value()
 
 	_var="$1"; : "${_var:?}"
 
-	echo "echo \${${_var}}" | config_load
+	echo "\${${_var}}" |
+	"$ROBSDCONFIG" -m "$_MODE" ${ROBSDCONF:+"-C${ROBSDCONF}"} -
 }
 
 # cvs_changelog -t tmp-dir
@@ -776,7 +776,7 @@ path_strip() {
 #
 # Get previous invocations.
 prev_release() {
-	"$ROBSDLS" -m "${_MODE}" ${ROBSDCONF:+"-f${ROBSDCONF}"} "$@"
+	"$ROBSDLS" -m "${_MODE}" ${ROBSDCONF:+"-C${ROBSDCONF}"} "$@"
 }
 
 # purge dir count
@@ -797,10 +797,8 @@ purge() {
 
 	_attic="$(config_value keep-dir)"
 
-	find "$_dir" -mindepth 1 -maxdepth 1 -type d |
-	grep -v "$_attic" |
-	sort -n |
-	tail -r |
+	prev_release -B |
+	sort -nr |
 	tail -n "+$((_n + 1))" |
 	while read -r _d; do
 		[ -d "$_attic" ] || mkdir "$_attic"
@@ -900,7 +898,7 @@ report() {
 	{
 		printf 'Subject: %s: %s: ' "$_MODE" "$(hostname -s)"
 		case "$_MODE" in
-		robsd-cross)	cross_report_subject;;
+		robsd-cross)	cross_report_subject -b "$_builddir";;
 		*)		;;
 		esac
 		printf '%s\n\n' "$_status"
@@ -929,7 +927,9 @@ report() {
 			cat "${_builddir}/tags"
 		fi
 
-		report_sizes "$(release_dir "$_builddir")"
+		if [ "$_MODE" = "robsd" ]; then
+			report_sizes "$(config_value bsd-reldir)"
+		fi
 	} >>"$_tmp"
 
 	_i=1
@@ -961,8 +961,6 @@ report() {
 		printf 'Duration: %s\n' \
 			"$(report_duration -d "$_name" "$_duration")"
 		printf 'Log: %s\n' "$(step_value log)"
-		# Honor step specific headers.
-		sed -n -e 's/^X-//p' "$_log"
 
 		report_log -e "$_exit" -n "$_name" -l "$_log" \
 			-t "${_builddir}/tmp" >"${_builddir}/tmp/log"
@@ -1103,7 +1101,7 @@ report_size() {
 	_prev="$(prev_release -B | head -1)"
 	[ -z "$_prev" ] && return 0
 
-	_path="$(release_dir "$_prev")/${_name}"
+	_path="${_prev}/rel/${_name}"
 	[ -e "$_path" ] || return 0
 
 	_s1="$(ls -l "$_f" | awk '{print $5}')"
@@ -1130,7 +1128,10 @@ report_sizes() {
 	_dir="$1"; : "${_dir:?}"
 	[ -d "$_dir" ] || return 0
 
-	find "$_dir" -type f | sort | while read -r _f; do
+	find "$_dir" -type f |
+	grep -Ev '\.diff\.[0-9]+$' |
+	sort |
+	while read -r _f; do
 		_siz="$(report_size "$_f")"
 		[ -z "$_siz" ] && continue
 
@@ -1191,25 +1192,6 @@ report_skip() {
 	return 1
 }
 
-# release_dir [-x] prefix
-#
-# Get the release directory with the given prefix applied.
-release_dir() {
-	local _prefix
-	local _suffix="rel"
-
-	while [ $# -gt 0 ]; do
-		case "$1" in
-		-x)	_suffix="relx";;
-		*)	break;;
-		esac
-		shift
-	done
-	_prefix="$1"; : "${_prefix:?}"
-
-	echo "${_prefix}/${_suffix}"
-}
-
 # robsd -b build-dir -s step-id
 #
 # Main loop shared between utilities.
@@ -1295,7 +1277,7 @@ robsd() {
 # Invoke robsd hook.
 robsd_hook() {
 	# Ignore non-zero exit.
-	"$ROBSDHOOK" -m "$_MODE" -V ${ROBSDCONF:+"-f${ROBSDCONF}"} "$@" || :
+	"$ROBSDHOOK" -m "$_MODE" -V ${ROBSDCONF:+"-C${ROBSDCONF}"} "$@" || :
 }
 
 # setmode mode
